@@ -7,13 +7,15 @@ use strict;
 use warnings;
 require Exporter;
 use Set::Infinite::Function;
-use Set::Infinite::Element_Inf qw(inf minus_inf);
+# use Set::Infinite;
 use Carp;
 use Time::Local;
 
 our @EXPORT = qw();
 our @EXPORT_OK = qw( %subs_offset2 %subs_offset1 %subs_offset1_init );
-# our @ISA = qw(Set::Infinite::Function); 
+
+our $inf = 10**10**10;    # $Set::Infinite::inf;  doesn't work! (why?)
+# carp " INF $inf ".&Set::Infinite::inf;
 
 =head2 NAME
 
@@ -33,7 +35,7 @@ Flavio Soibelmann Glock - fglock@pucrs.br
 
 =cut
 
-# our $day_size =    $Set::Infinite::Quantize_Date::day_size; 
+ 
 our $day_size =    timegm(0,0,0,2,3,2001) - timegm(0,0,0,1,3,2001);
 our $hour_size =   $day_size / 24;
 our $minute_size = $hour_size / 60;
@@ -63,7 +65,7 @@ our %subs_offset2 = (
 		# -1 = last saturday from today (not today, even if today were saturday)
 		# -2 = last friday
 		my ($self, $index1, $index2) = @_;
-		return ($self, $self, 0) if $self == &inf;
+		return ($self, $self, 0) if $self == $inf;
 		# my $class = ref($self);
 		my @date = gmtime( $self ); 
 		my $wday = $date[6];
@@ -96,7 +98,7 @@ our %subs_offset2 = (
 	},
 	years => 	sub {
 		my ($self, $index, $index2) = @_;
-		return ($self, $self, 0) if $self == &inf;
+		return ($self, $self, 0) if $self == $inf;
 		# my $class = ref($self);
 		# print " [ofs:year:$self -- $index]\n";
 		my @date = gmtime( $self ); 
@@ -112,8 +114,8 @@ our %subs_offset2 = (
 	},
 	months => 	sub {
 		my ($self, $index, $index2) = @_;
-		# print " [ofs:month:$self -- $index]\n";
-		return ($self, $self, 0) if $self == &inf;
+		# carp " [ofs:month:$self -- $index -- $inf]";
+		return ($self, $self, 0) if $self == $inf;
 		# my $class = ref($self);
 		my @date = gmtime( $self );
 
@@ -180,10 +182,6 @@ our %subs_offset2 = (
 	},
 );
 
-# our $day_size = timegm(0,0,0,2,3,2001) - timegm(0,0,0,1,3,2001);
-# our $hour_size = $day_size / 24;
-# our $minute_size = $hour_size / 60;
-# our $second_size = $minute_size / 60;
 
 our @week_start = ( 0, -1, -2, -3, 3, 2, 1, 0, -1, -2, -3, 3, 2, 1, 0 );
 
@@ -218,7 +216,6 @@ our %subs_offset1 = (
 		my @time = gmtime($epoch);
 		# print " [QT_D:weekyears:$self->{date_begin}[5] + $self->{quant} * $index]\n";
 		# year modulo week
-		# print " [QT:weekyears: ",$self->{date_begin}[5] + $self->{quant} * $index," epoch=$epoch ]\n";
 		# print " [QT:weekyears: time = ",join(";", @time )," ]\n";
 		$epoch += ( $week_start[$time[6] + 7 - $self->{wkst}] ) * $day_size;
 		# print " [QT:weekyears: week=",join(";", gmtime($epoch) )," wkst=$self->{wkst} tbl[",$time[6] + 7 - $self->{wkst},"]=",$week_start[$time[6] + 7 - $self->{wkst}]," ]\n\n";
