@@ -86,7 +86,7 @@ package Set::Infinite::Date;
 
 my $DEBUG = 1;
 # @ISA = qw(Set::Infinite::Simple); # DON'T !
-@ISA = qw(Set::Infinite::Element_Inf);  # is_null
+# @ISA = qw(Set::Infinite::Element_Inf);  # is_null
 @EXPORT = qw();
 @EXPORT_OK = qw(
 	time2date date2time time2hour hour2time quantizer day_size
@@ -94,7 +94,7 @@ my $DEBUG = 1;
 
 use strict;
 use Time::Local;
-use Set::Infinite::Element_Inf;
+# use Set::Infinite::Element_Inf;
 
 #--- THIS FUNCTION IS (HEAVILY) MODIFIED FROM HTTP::Date -- Copyright 1995-1999, Gisle Aas
 
@@ -244,28 +244,9 @@ sub add {
 
 sub spaceship {
 	my ($tmp1, $tmp2, $inverted) = @_;
-	# print " [DATE:CMP:",caller(1),"]\n";
-	# print " $tmp1 ";
 
 	return 1 unless defined($tmp2);
 
-	# if ($DEBUG) {
-		# if ($tmp2->isa(__PACKAGE__)) {
-		#	print " [DATE:CMP:$inverted:",$tmp1->{a};
-		#	print " [ ",$tmp2,": ", ref($tmp2), ": ", ref(\$tmp2), "]\n";
-		#	print "    <=>",$tmp2->{a},"]\n";
-		#}
-		# { else {
-		#	print " [DATE:CMP:$inverted:",$tmp1;
-		#	print " [ ",$tmp2,": ", ref($tmp2), ": ", ref(\$tmp2), "]\n";
-		#	print "    <=>",$tmp2,"]\n";
-		# }
-	# }
-
-	# $tmp2 = Set::Infinite::Date->new($tmp2) unless ref($tmp2) and $tmp2->isa(__PACKAGE__);
-
-	# print " ",ref($tmp2);
-
 	if ( ref($tmp2) eq __PACKAGE__ ) {
 		if ($inverted) {
 			return ( $tmp2->{a} <=> $tmp1->{a} );
@@ -279,12 +260,15 @@ sub spaceship {
 	return ( $tmp1->{a} <=> $tmp2 );
 }
 
-# sub cmp {
-#	return spaceship @_;
-# }
-
 sub new {
-	my ($self) = bless {}, shift;
+	my $class = shift;
+	my $self;
+	if (ref($class)) {
+		$self = bless { mode => $class->{mode} }, ref($class);
+	}
+	else {
+		$self = bless {}, $class;
+	}
 	my $tmp = shift;
 
 	if ((not defined $tmp) or ($tmp eq '')) {
@@ -302,17 +286,17 @@ sub new {
 	if ($tmp =~ /\d[\/\.\-]\d/) {
 		# $self->{string} = $tmp;
 		$self->{a} = date2time($tmp);
-		$self->{mode} = 2;
+		$self->{mode} = 2 unless $self->{mode};
 	}
 	elsif ($tmp =~ /\d\:\d/) {
 		# $self->{string} = $tmp;
 		$self->{a} = hour2time($tmp);
-		$self->{mode} = 1;
+		$self->{mode} = 1 unless $self->{mode};
 	}
 	else {
 		# $self->{string} = $tmp;
 		$self->{a} = $tmp;
-		$self->{mode} = 0;
+		$self->{mode} = 0 unless $self->{mode};
 	}
 	$date_cache{$tmp} = $self;
 	return $self;
@@ -353,8 +337,4 @@ sub as_string {
 	return $self->{string};
 }
 
-# sub epoch {
-#	return 0 + $_[0]->{a};
-# }
-
-1;
\ No newline at end of file
+1;
