@@ -7,6 +7,9 @@ use strict;
 use warnings;
 
 require Exporter;
+use Tie::Array;
+
+our @ISA = qw( Tie::StdArray Exporter );
 our $VERSION = "0.01";
 our @EXPORT = qw();
 our @EXPORT_OK = qw();
@@ -37,6 +40,8 @@ Derived functions should register themselves automatically with Set::Infinite
 
 =head2 CHANGES
 
+    use Tie::Array
+
 =head2 AUTHOR
 
 Flavio Soibelmann Glock - fglock@pucrs.br
@@ -94,14 +99,4 @@ sub TIEARRAY {
 	return $self;
 }
 
-sub STORESIZE {	return @_; }
-
-sub CLEAR { my ($self) = shift; return @_; }
-
-sub EXTEND { return @_; }
-
-sub STORE { return @_; }
-
-sub DESTROY { }
-
 1;
