@@ -17,7 +17,7 @@ our @EXPORT_OK = qw();
 use Time::Local;
 use Set::Infinite qw(type);
 use Set::Infinite::Arithmetic;
-use Set::Infinite::Element_Inf qw(inf);
+# use Set::Infinite::Element_Inf qw(inf);
 
 =head2 NAME
 
@@ -83,7 +83,7 @@ sub new {
 
 	my $min = $self->{parent}->min;
 	# print " [MIN:$min] \n";
-	if (Set::Infinite::Element_Inf->is_null($min)) {
+	unless (defined $min) {
 		# print " [NULL!]\n";
 		$self->{size} = -1;
 		return $self;	
@@ -118,7 +118,7 @@ sub new {
 	&{ $Set::Infinite::Arithmetic::subs_offset1_init{$self->{unit}} } ($self);
 
 	$self->{time2_end} = $self->{parent}->max;
-	# print " [time2_end isa ", ref($self->{time2_end}), "] ";
+	# print " [time2_end isa ", $self->{time2_end}, "=", ref($self->{time2_end}), "] ";
 
 	# print " [QD:SIZE: = 2 + ($self->{time2_end} - $self->{first}) /  ($self->{quant} * $self->{mult})]\n";
 
@@ -156,8 +156,9 @@ sub FETCH {
 		$Memoize{$self->{memo}}{$index + $self->{offset}} = $tmp;
 	}
 
+        # print " FETCH ",%$tmp,":",ref($tmp),"\n";
 	if ($self->{strict} and not $self->{strict}->intersects($tmp)) {
-		$tmp = Set::Infinite::Simple->simple_null;
+		$tmp = undef;
 	}
 	$self->{cache}->{$index} = $tmp;
 	return $tmp;
@@ -168,45 +169,21 @@ sub _FETCH {
 	my $tmp;
 	my ($this, $next);
 
-	# print "*";
-	# print " [QD:fetch:$index] ";
-
 	$this = &{ $Set::Infinite::Arithmetic::subs_offset1{$self->{unit}} } ($self, $index);
 	$next = &{ $Set::Infinite::Arithmetic::subs_offset1{$self->{unit}} } ($self, $index + 1);
 
-	# if ($this > $self->{time2_end}) {
-	#	$self->{size} = $index if $self->{size} > $index;
-	#	$self->{cache}->{$index} = Set::Infinite::Simple->simple_null;
-	#	return $self->{cache}->{$index};
-	# }
+        # print " Q[$this,$next] \n";
+	return Set::Infinite::_simple_fastnew($this, $next, 0, 1 ) unless $self->{fixtype};
 
-	# print " [QD:fetch:new($this,$next)] ";
-
-	return Set::Infinite::Simple->fastnew($this, $next, 0, 1 ) unless $self->{fixtype};
-
-	$tmp = Set::Infinite::Simple->new($this,$next, $self->{type} )->open_end(1);
-	# my $tmp = Set::Infinite::Simple->fastnew($this,$next)->open_end(1);
-
-	# if ((ref($tmp->{a})) and ($tmp->{a}->can('mode'))) {   
+	$tmp = Set::Infinite::_simple_new($this,$next, $self->{type} );
+    $tmp->{open_end} = 1;
+  
 	if (exists $self->{mode}) {
 		$tmp->{a}->mode($self->{mode});
 		$tmp->{b}->mode($self->{mode});
 	}
-	# print " [QD:fetch:$tmp] ";
 
 	return $tmp;
-
-	# global "memoize"
-	#if ($self->{memo}) {
-	#	$Memoize{$self->{memo}}{$index + $self->{offset}} = $tmp;
-	#}
-	#
-	#if (not $self->{strict} or ($self->{strict}->intersects($tmp))) {
-	#	$self->{cache}->{$index} = $tmp;
-	#	return $tmp;
-	#}
-	#$self->{cache}->{$index} = Set::Infinite::Simple->simple_null;
-	#return $self->{cache}->{$index};
 }
 
 # TIE
